summaryrefslogtreecommitdiffstats
path: root/superkaramba/src/clickmap.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:52:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:52:55 +0000
commit5f5ee2367157176ed223b86343eb0a9e4022e020 (patch)
tree6a9c87f14ee38e90eff3c77c784f14e4f38fd5a1 /superkaramba/src/clickmap.cpp
parent4facf42feec57b22dcf46badc115ad6c5b5cc512 (diff)
downloadtdeutils-5f5ee2367157176ed223b86343eb0a9e4022e020.tar.gz
tdeutils-5f5ee2367157176ed223b86343eb0a9e4022e020.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeutils@1157653 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'superkaramba/src/clickmap.cpp')
-rw-r--r--superkaramba/src/clickmap.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/superkaramba/src/clickmap.cpp b/superkaramba/src/clickmap.cpp
index 62b4376..2189916 100644
--- a/superkaramba/src/clickmap.cpp
+++ b/superkaramba/src/clickmap.cpp
@@ -9,7 +9,7 @@
***************************************************************************/
#include "clickmap.h"
-#include <qregexp.h>
+#include <tqregexp.h>
#include <krun.h>
ClickMap::ClickMap(karamba* k, int x, int y, int w, int h )
@@ -38,14 +38,14 @@ void ClickMap::setTextProps( TextField *t )
text = *t;
}
-bool ClickMap::click( QMouseEvent *e ) {
+bool ClickMap::click( TQMouseEvent *e ) {
//Don't load the web page if the click isn't for us
if (boundingBox.contains(e->x(), e->y())) {
int index = ((e -> y() - getY()) / text.getLineHeight()) + 1;
if (index >= 1 && index <= (int)displays.count()) {
// qDebug( "You clicked item " + QString::number( index ) + ", " +
// displays[index - 1] + " " + links[index - 1] );
KRun::runCommand("konqueror " + links[index - 1]);
}
@@ -53,13 +53,13 @@ bool ClickMap::click( QMouseEvent *e ) {
return false;
}
-void ClickMap::mUpdate( QPainter *p )
+void ClickMap::mUpdate( TQPainter *p )
{
int i = 0; //text.getLineHeight();
int row = 1;
p->setFont(text.getFont());
- QStringList::Iterator it = displays.begin();
+ TQStringList::Iterator it = displays.begin();
while( it != displays.end() && (row <= getHeight() || getHeight() == -1 ) )
{
p->setPen( text.getColor() );
@@ -71,9 +71,9 @@ void ClickMap::mUpdate( QPainter *p )
}
}
-void ClickMap::setValue( QString v )
+void ClickMap::setValue( TQString v )
{
- QRegExp rx("^http://", false );
+ TQRegExp rx("^http://", false );
if ( rx.search( v ) == -1 )
{
displays.append( v );
@@ -38,14 +38,14 @@ void ClickMap::setTextProps( TextField *t )
int index = ((e -> y() - getY()) / text.getLineHeight()) + 1;
if (index >= 1 && index <= (int)displays.count()) {
- // qDebug( "You clicked item " + QString::number( index ) + ", " +
+ // qDebug( "You clicked item " + TQString::number( index ) + ", " +
// displays[index - 1] + " " + links[index - 1] );
KRun::runCommand("konqueror " + links[index - 1]);